@@ -85,7 +85,26 @@ def download_wbt(verbose=True):
                     zip_ref.extractall(pkg_dir)
             else:  # Decompress Linux tar file
                 with tarfile.open(zip_name, "r") as tar_ref:
-                    tar_ref.extractall(pkg_dir)
+                    def is_within_directory(directory, target):
+                        
+                        abs_directory = os.path.abspath(directory)
+                        abs_target = os.path.abspath(target)
+                    
+                        prefix = os.path.commonprefix([abs_directory, abs_target])
+                        
+                        return prefix == abs_directory
+                    
+                    def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+                    
+                        for member in tar.getmembers():
+                            member_path = os.path.join(path, member.name)
+                            if not is_within_directory(path, member_path):
+                                raise Exception("Attempted Path Traversal in Tar File")
+                    
+                        tar.extractall(path, members, numeric_owner=numeric_owner) 
+                        
+                    
+                    safe_extract(tar_ref, pkg_dir)
             if verbose:
                 print("WhiteboxTools package directory: {}".format(pkg_dir))
 
@@ -120,9 +139,9 @@ def download_wbt(verbose=True):
             except:
                 pass
 
-            # The official WhiteboxTools Linux binary from whiteboxgeo.com requires GLIBC 2.29,
-            # which is incompatible with Google Colab that uses GLIBC 2.27. The following code
-            # downloads the binary that is compatible with Google Colab.
+            # # The official WhiteboxTools Linux binary from whiteboxgeo.com requires GLIBC 2.29,
+            # # which is incompatible with Google Colab that uses GLIBC 2.27. The following code
+            # # downloads the binary that is compatible with Google Colab.
             if "google.colab" in sys.modules:
                 url = "https://github.com/giswqs/whitebox-bin/raw/master/WhiteboxTools_ubuntu_18.04.zip"
                 zip_name = os.path.join(pkg_dir, os.path.basename(url))
@@ -143,7 +162,7 @@ def download_wbt(verbose=True):
                 except Exception as e:
                     print(e)
 
-            webbrowser.open('https://www.whiteboxgeo.com/', new=2)
+            webbrowser.open("https://www.whiteboxgeo.com/", new=2)
 
         if not os.path.exists(work_dir):
             if verbose:
